<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block title %}AtlasBridge Dashboard{% endblock %}</title>
    <link rel="icon" type="image/png" sizes="32x32" href="/static/favicon/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/static/favicon/favicon-16x16.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/static/favicon/apple-touch-icon.png">
    <link rel="stylesheet" href="/static/style.css">
</head>
<body>
    <header>
        <div class="banner">READ-ONLY GOVERNANCE VIEW &mdash; LOCAL EXECUTION ONLY</div>
        <nav>
            <a href="/" class="brand">AtlasBridge</a>
            <button class="nav-toggle" id="nav-toggle" aria-label="Toggle navigation">&#9776;</button>
            <div class="nav-links" id="nav-links">
                <a href="/">Home</a>
                <a href="/traces">Traces</a>
                <a href="/integrity">Integrity</a>
                <button id="theme-toggle" class="nav-btn" title="Toggle light/dark theme">Theme</button>
            </div>
        </nav>
    </header>
    <main>
        {% block content %}{% endblock %}
    </main>
    <footer>
        <p>AtlasBridge Dashboard &mdash; localhost-only, read-only viewer</p>
    </footer>
    <script src="/static/dashboard.js"></script>
</body>
</html>
